/**
 * Copyright 2016 Confluent Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package kafka

import "C"

// bool2int converts a bool to a C.int (1 or 0)
func bool2cint(b bool) C.int {
	if b {
		return 1
	}
	return 0
}

// cint2bool converts a C.int to a bool
func cint2bool(v C.int) bool {
	if v == 0 {
		return false
	}
	return true
}
